<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | MacIG Plug-in for Geeklog 1.3.x                                           |
// +---------------------------------------------------------------------------+
// | function.inc                                                              |
// |                                                                           |
// | Core functions for the MacIG plugin.                                      |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2003 by the following authors:                              |
// |                                                                           |
// | Authors: Dirk Haun  - dirk@haun-online.de                                 |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//
// $Id: functions.inc,v 1.1.1.1 2003/10/25 21:18:08 dirk Exp $

/**
* Create a list of all Geeklog groups that have 'MacIG' but not 'Admin' in
* their group name.
*/
function macig_getAll ()
{
    global $_TABLES;

    $macigs = array ();

    $result = DB_query ("SELECT grp_id,grp_name FROM {$_TABLES['groups']} WHERE grp_name LIKE '%MacIG%' ORDER by grp_name");
    $num = DB_numRows ($result);
    if ($num > 0) {
        for ($i = 0; $i < $num; $i++) {
            $A = DB_fetchArray ($result);
            if (stristr ($A['grp_name'], 'admin') === false) {
                $macigs[$A['grp_name']] = $A['grp_id'];
            }
        }
    }

    return $macigs;
}

/**
* Create a list of all (MacIG) groups of which user $uid is a member.
*/
function macig_getGroups ($uid)
{
    global $_TABLES;

    $groups = array ();

    $result = DB_query ("SELECT ug_main_grp_id,grp_name FROM {$_TABLES['group_assignments']},{$_TABLES['groups']} WHERE grp_id = ug_main_grp_id AND ug_uid = $uid");
    $num = DB_numRows ($result);
    for ($i = 0; $i < $num; $i++) {
        $A = DB_fetchArray ($result);
        $groups[$A['grp_name']] = $A['ug_main_grp_id'];
    }

   return $groups;
}

/**
* Create a set of checkboxes with all available MacIG groups.
*/
function macig_makeSelection ($uid)
{
    global $_TABLES;

    $retval = '';

    $grplist = macig_getGroups ($uid);
    $macigs = macig_getAll ();

    foreach ($macigs as $name => $id) {
        $retval .= '<input type="checkbox" name="macig_group[]" value="'
                . $id . '"';
        if ($grplist[$name] == $id) {
            $retval .= ' checked="checked"';
        }
        $retval .= '>' . $name . '<br>' . LB;
    }

    return $retval;
}

/**
* Create a list (for display) listing all the MacIG groups of which user $uid
* is a member (something like "MacIG Heilbronn, MacIG Ludwigsburg").
*/
function macig_makeList ($uid)
{
    global $_TABLES;

    $retval = '';

    $grplist = macig_getGroups ($uid);
    $macigs = macig_getAll ();

    $both = array_intersect ($macigs, $grplist);

    if (sizeof ($both) > 0) {
        $retval = implode (', ', array_keys ($both));
    } else {
        $retval = '<i>keine</i>';
    }

    return $retval;
}

/**
* Plugin API: Set variables to be used in preferences/profile.thtml
* (i.e. where users can edit their profile).
*/
function plugin_profilevariablesedit_macig ($uid, &$template)
{
    $template->set_var ('lang_macig_macig', 'MacIG');
    $template->set_var ('lang_macig_text', 'MacIGs, in denen Du aktiv bist');
    $template->set_var ('macig_selection', macig_makeSelection ($uid));
}

/**
* Plugin API: Set variables to be used in users/profile.thtml
* (i.e. when displaying a user's profile).
*/
function plugin_profilevariablesdisplay_macig ($uid, &$template)
{
    $template->set_var ('lang_macig_macig', 'MacIG');
    $template->set_var ('macig_active', macig_makeList ($uid));
}

/**
* Plugin API: Save any changes the user may have made to our variables
* (in our case that means adding or removing the user to/from groups).
*/
function plugin_profileextrassave_macig ()
{
    global $_TABLES, $HTTP_POST_VARS, $REMOTE_ADDR;

    $uid = $HTTP_POST_VARS['uid'];
    if (empty ($uid)) {
        $uid = DB_getItem ($_TABLES['users'], 'uid',
                          "username = '{$HTTP_POST_VARS['username']}'");
    }

    $active = array_values ($HTTP_POST_VARS['macig_group']);
    $macigs = macig_getAll ();

    foreach ($macigs as $name => $ig) {
        DB_query ("DELETE FROM {$_TABLES['group_assignments']} WHERE ug_uid = $uid AND ug_main_grp_id = $ig");
    }

    foreach ($active as $ac) {
        if (in_array ($ac, $macigs)) {
            DB_query ("INSERT INTO {$_TABLES['group_assignments']} (ug_main_grp_id, ug_uid) VALUES ($ac, $uid)");
        } else {
            COM_errorLog ("Group id manipulation: User $uid (IP $REMOTE_ADDR) tried to become a member of group $ac", 1);
        }
    }
}

/**
* Plugin API: Uninstall function.
*/
function plugin_uninstall_macig ()
{
    global $_TABLES;

    DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'macig'");
}

?>
